#if !defined(M_POLFIT_H)
#define M_POLFIT_H

/*
   --- structure describing parameters
*/
struct SPOLFITPAR {
   unsigned long lFlag;               /* POLFIT_NOERR,... */
   int np;                            /* inp: # of parameters */
   int nDF;                           /* out: # degrees of freedom */
   double dChisq,                     /* out: chisquare */
          dProb,                      /* out: probability */
          dConf;                      /* inp: (0..1) confidence limit */
   double *pdPar, *pdErr;             /* out: [np] parameters, errors */
   double *pdCovar;                   /* out: [np*np] covariance matrix */
   long   *plCol, *plRow;
};

int polfitParAlloc  ( int, struct SPOLFITPAR *, unsigned long );
int polfitParFree   (      struct SPOLFITPAR *, unsigned long );
int polfitParInspect(      struct SPOLFITPAR *, unsigned long );

/*
   --- structure describing data
*/
struct SPOLFITDATA {
   unsigned long lFlag;
   int nn;                            /* inp: # of data points */
   double *pdW;                       /* scratch: weights */
   double *pdX, *pddXm, *pddXp;       /* inp: x-values and -errors */
   double *pdY, *pddYm, *pddYp;       /* inp: y-values and -errors */
   double *pdF, *pddFm, *pddFp;       /* out: function values and -errors */
};

int polfitDataAlloc  ( int, struct SPOLFITDATA *, unsigned long );
int polfitDataFree   (      struct SPOLFITDATA *, unsigned long );
int polfitDataDup    (      struct SPOLFITDATA *, struct SPOLFITDATA *, unsigned long );
int polfitDataInspect(      struct SPOLFITDATA *, unsigned long );

int polfitFit( struct SPOLFITDATA *, struct SPOLFITPAR *, unsigned long );
int polfitFct( struct SPOLFITDATA *, struct SPOLFITPAR *, unsigned long );

                                      /* flags */
#define POLFIT_DEBUG 0x80000000       /* global debug */
#define POLFIT_NOERR 0x00010000       /* unknown data errors on input */

#define ERRPOLFIT_SYS          -1
#define ERRPOLFIT_BADADDR      -2
#define ERRPOLFIT_BADPARCOUNT  -3
#define ERRPOLFIT_BADDATACOUNT -4
#define ERRPOLFIT_NDF          -5
#define ERRPOLFIT_INVMAT       -6

#endif
